# Luxsci.WebAidesApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**addUpdateWebAideEntries**](WebAidesApi.md#addUpdateWebAideEntries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/import | 
[**deleteWebAide**](WebAidesApi.md#deleteWebAide) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**deleteWebAideEntries**](WebAidesApi.md#deleteWebAideEntries) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/delete | 
[**deleteWebAideEntry**](WebAidesApi.md#deleteWebAideEntry) | **DELETE** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
[**getCalendarEntriesDateRange**](WebAidesApi.md#getCalendarEntriesDateRange) | **GET** /user/{username}/webaides/calendar/{webaide_id}/entries/date_range | 
[**getWebAide**](WebAidesApi.md#getWebAide) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**getWebAideChanges**](WebAidesApi.md#getWebAideChanges) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries/changes | 
[**getWebAideEntries**](WebAidesApi.md#getWebAideEntries) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/entries | 
[**getWebAideEntry**](WebAidesApi.md#getWebAideEntry) | **GET** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 
[**getWebAides**](WebAidesApi.md#getWebAides) | **GET** /user/{username}/webaides/{webaide_type} | 
[**newWebAide**](WebAidesApi.md#newWebAide) | **POST** /user/{username}/webaides/{webaide_type} | 
[**newWebAideEntry**](WebAidesApi.md#newWebAideEntry) | **POST** /user/{username}/webaides/{webaide_type}/{webaide_id} | 
[**updateWebAideEntry**](WebAidesApi.md#updateWebAideEntry) | **PUT** /user/{username}/webaides/{webaide_type}/{webaide_id}/{entry_id} | 

<a name="addUpdateWebAideEntries"></a>
# **addUpdateWebAideEntries**
> InlineResponse20031 addUpdateWebAideEntries(username, webaideType, webaideId, opts)



Add/update multiple entries of a WebAide all at once.  Address Book Imports: SecureLine data can be sent in this way as well (i.e. Escrow question and answer, PGP key, S/MIME key, etc.). SecureLine data is imported if and only if the “SecureLine Mode” field is present and not empty for an entry. Any entries that are updated and for which “SecureLine Mode” is left blank, will have their existing SecureLine settings left “as-is”.  Note: Each WebAide is limited to 25,000 entries by default. If your WebAide has this many entries (or more), then this AddUpdateWebAideEntries command will return an error (even if you are only intending to do updates). If you need larger WebAides, please contact support. Very large WebAides may require use of a dedicated server.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Update Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
  'body': new Luxsci.EntriesImportBody(), // EntriesImportBody | 
};
apiInstance.addUpdateWebAideEntries(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **body** | [**EntriesImportBody**](EntriesImportBody.md)|  | [optional] 

### Return type

[**InlineResponse20031**](InlineResponse20031.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteWebAide"></a>
# **deleteWebAide**
> InlineResponse201 deleteWebAide(username, webaideType, webaideId, opts)



Delete a WebAide of type &#x60;webaide_type&#x60; whose unique ID is &#x60;webaide_id&#x60;. This WebAide must be owned by the user in question. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
};
apiInstance.deleteWebAide(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteWebAideEntries"></a>
# **deleteWebAideEntries**
> InlineResponse20029 deleteWebAideEntries(username, webaideType, webaideId, opts)



Delete multiple entries from a WebAide all at once. (Since we are not deleting an individual entity at a specific address, this is a POST instead of a DELETE method). See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
  'body': new Luxsci.EntriesDeleteBody(), // EntriesDeleteBody | 
};
apiInstance.deleteWebAideEntries(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **body** | [**EntriesDeleteBody**](EntriesDeleteBody.md)|  | [optional] 

### Return type

[**InlineResponse20029**](InlineResponse20029.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteWebAideEntry"></a>
# **deleteWebAideEntry**
> InlineResponse20026 deleteWebAideEntry(username, webaideType, webaideId, entryId, opts)



Delete an existing WebAide Entry. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Delete Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let entryId = "entryId_example"; // String | 
let opts = { 
};
apiInstance.deleteWebAideEntry(username, webaideType, webaideId, entryId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **entryId** | **String**|  | 

### Return type

[**InlineResponse20026**](InlineResponse20026.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getCalendarEntriesDateRange"></a>
# **getCalendarEntriesDateRange**
> InlineResponse20028 getCalendarEntriesDateRange(username, webaideId, before, from, opts)



Gets a list of entries in a specified Calendar WebAide that fall within a specified range of dates. For recurring entries, the entry will be returned if any of its instances fall within the specified date range. The date range is taken to be dates in GMT. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to WebAide Calendars; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let before = "before_example"; // String | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied) Required. Entries that contain events before this date.
let from = "from_example"; // String | DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied)<br><br>Required. Entries that contain events on or after this date.
let opts = { 
  'entries': "entries_example", // String | Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”<br><br>Optional. If included, the search is restricted to only entries in this list.<br><br>Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes.
};
apiInstance.getCalendarEntriesDateRange(username, webaideId, before, from, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideId** | **String**|  | 
 **before** | **String**| DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied) Required. Entries that contain events before this date. | 
 **from** | **String**| DATE: “YYYY-MM-DD” in GMT (where 00:00:00 GMT is implied)&lt;br&gt;&lt;br&gt;Required. Entries that contain events on or after this date. | 
 **entries** | **String**| Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”&lt;br&gt;&lt;br&gt;Optional. If included, the search is restricted to only entries in this list.&lt;br&gt;&lt;br&gt;Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. | [optional] 

### Return type

[**InlineResponse20028**](InlineResponse20028.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getWebAide"></a>
# **getWebAide**
> InlineResponse20022 getWebAide(username, webaideType, webaideId, opts)



This call is like &#x60;getWebAides&#x60;, except that the call is simplified and targeted at a specific, single WebAide. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
  'changes': "changes_example", // String | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner.
};
apiInstance.getWebAide(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **changes** | **String**| Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/updates/deletes since the specified date.&lt;br&gt;&lt;br&gt;Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.&lt;br&gt;&lt;br&gt;Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. | [optional] 

### Return type

[**InlineResponse20022**](InlineResponse20022.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getWebAideChanges"></a>
# **getWebAideChanges**
> InlineResponse20030 getWebAideChanges(username, webaideType, webaideId, modified, opts)



Return all WebAide entries added, changed, or deleted since a particular time. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let modified = "modified_example"; // String | Timestamp “YYYYMMDDHHMMSS” in GMT or “YYYY-MM-DD HH:MM:SS” in GMT<br><br>Return all WebAide entries added, changed, or deleted since this timestamp. If you specify “0” here, it will return a list of all entries that exist now and all that have been deleted.
let opts = { 
};
apiInstance.getWebAideChanges(username, webaideType, webaideId, modified, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **modified** | **String**| Timestamp “YYYYMMDDHHMMSS” in GMT or “YYYY-MM-DD HH:MM:SS” in GMT&lt;br&gt;&lt;br&gt;Return all WebAide entries added, changed, or deleted since this timestamp. If you specify “0” here, it will return a list of all entries that exist now and all that have been deleted. | 

### Return type

[**InlineResponse20030**](InlineResponse20030.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getWebAideEntries"></a>
# **getWebAideEntries**
> InlineResponse20027 getWebAideEntries(username, webaideType, webaideId, opts)



Retrieve the detailed contents of all WebAide entries matching a query. See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
  'entries': ["entries_example"], // [String] | Optional. Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”.  If included, the search is restricted to only entries in this list.  Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes.
  'limit': 500, // Number | Optional. Integer 1 to 500. How many entries to return (maximum). Default is 500.
  'resume': 0, // Number | Integer:1 or 0. If 0 (the default), begin a new search. If 1, continue the previous search. When returning successive “pages” or entries, use resume for faster and more consistent results.
  'secureline': 56, // Number | Integer 1 or 0 If specified as ‘1’, SecureLine-specific Address Book fields are included in the export. I.e., this includes the SecureLine Escrow Question/Answer pair and/or PGP and S/MIME public keys.
  'showcomplete': 56, // Number | Integer 1 or 0 If specified as ‘1’, get completed tasks for ‘Tasks’ WebAides. By default, only uncompleted tasks are returned.
  'sort': "sort_example", // String | Optional method by which the returned entries should be sorted.
  'start': 0, // Number | Optional. The default is 0. Index in the list of all entries from which to start the result set. Use this to return successive “pages” of entries.
  'timezone': "timezone_example", // String | Time zone code. The time zone to use for Calendar/Task dates and times. The user’s default time zone is used if no time zone is specified.
};
apiInstance.getWebAideEntries(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **entries** | [**[String]**](String.md)| Optional. Comma-delimited list of entry Unique IDs. e.g. “10786,77892,23”.  If included, the search is restricted to only entries in this list.  Note, if you want to use a very long list of entries, you might want to use several requests so that you do not exceed the maximum URL query string size of 8190 bytes. | [optional] 
 **limit** | **Number**| Optional. Integer 1 to 500. How many entries to return (maximum). Default is 500. | [optional] [default to 500]
 **resume** | **Number**| Integer:1 or 0. If 0 (the default), begin a new search. If 1, continue the previous search. When returning successive “pages” or entries, use resume for faster and more consistent results. | [optional] [default to 0]
 **secureline** | **Number**| Integer 1 or 0 If specified as ‘1’, SecureLine-specific Address Book fields are included in the export. I.e., this includes the SecureLine Escrow Question/Answer pair and/or PGP and S/MIME public keys. | [optional] 
 **showcomplete** | **Number**| Integer 1 or 0 If specified as ‘1’, get completed tasks for ‘Tasks’ WebAides. By default, only uncompleted tasks are returned. | [optional] 
 **sort** | **String**| Optional method by which the returned entries should be sorted. | [optional] 
 **start** | **Number**| Optional. The default is 0. Index in the list of all entries from which to start the result set. Use this to return successive “pages” of entries. | [optional] [default to 0]
 **timezone** | **String**| Time zone code. The time zone to use for Calendar/Task dates and times. The user’s default time zone is used if no time zone is specified. | [optional] 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getWebAideEntry"></a>
# **getWebAideEntry**
> InlineResponse2003 getWebAideEntry(username, webaideType, webaideId, entryId, opts)



Retrieve the detailed contents of a specific WebAide entry. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let entryId = "entryId_example"; // String | 
let opts = { 
};
apiInstance.getWebAideEntry(username, webaideType, webaideId, entryId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **entryId** | **String**|  | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getWebAides"></a>
# **getWebAides**
> InlineResponse20022 getWebAides(username, webaideType, opts)



Return a list of all WebAides accessible to the specified user, that are also of the indicated type. You can use the query string to add filters to narrow down the results. See also [WebAide definitions](/rest-api/webaides.html). {{ACL: Access to that specific type of WebAides; Read Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let opts = { 
  'subscribed': "subscribed_example", // String | Filter by WebAide subscription status<ul><li>all - select all</li><li>subscribed - return those subscribed</li><li>unsubscribed - return those not subscribed</li><li>tosync - return those tagged for synchronization with MobileSync.</li>
  'ids': ["ids_example"], // [String] | List of the numerical WebAide IDs eligible to be returned.
  'permissions': ["permissions_example"], // [String] | Values can include those in the webaide_permission list. Select only WebAides where the user has all of the indicated permissions
  'modified': "modified_example", // String | DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. Return all WebAides that have had any entry created, deleted, or modified on or after this date and time. Values can include those in the webaide_permission list.
  'changes': "changes_example", // String | Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/ updates/deletes since the specified date.<br><br>Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.<br><br>Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner.
};
apiInstance.getWebAides(username, webaideType, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **subscribed** | **String**| Filter by WebAide subscription status&lt;ul&gt;&lt;li&gt;all - select all&lt;/li&gt;&lt;li&gt;subscribed - return those subscribed&lt;/li&gt;&lt;li&gt;unsubscribed - return those not subscribed&lt;/li&gt;&lt;li&gt;tosync - return those tagged for synchronization with MobileSync.&lt;/li&gt; | [optional] 
 **ids** | [**[String]**](String.md)| List of the numerical WebAide IDs eligible to be returned. | [optional] 
 **permissions** | [**[String]**](String.md)| Values can include those in the webaide_permission list. Select only WebAides where the user has all of the indicated permissions | [optional] 
 **modified** | **String**| DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. Return all WebAides that have had any entry created, deleted, or modified on or after this date and time. Values can include those in the webaide_permission list. | [optional] 
 **changes** | **String**| Optional. DateTime in GMT in the format: YYYY-MM-DD HH:MM:SS. If this is provided, a sub call to “GetWebAideChanges” will be made for each returned WebAide, giving you summary counts of numbers of entries and adds/ updates/deletes since the specified date.&lt;br&gt;&lt;br&gt;Specify an old date (e.g. “2000-01-01”) if all you care about is the total number of entries.&lt;br&gt;&lt;br&gt;Use of “changes” is the recommended way to get the number of entries in one or more WebAides in an efficient manner. | [optional] 

### Return type

[**InlineResponse20022**](InlineResponse20022.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newWebAide"></a>
# **newWebAide**
> InlineResponse20023 newWebAide(username, webaideType, opts)



Create a new WebAide of type webaide_type. E.g. creation of a new “Address Book”.   Note: Each user is limited to 500 WebAides of each type. Trying to create more will result in an error being returned.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Update Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let opts = { 
  'body': new Luxsci.WebaidesWebaideTypeBody(), // WebaidesWebaideTypeBody | 
};
apiInstance.newWebAide(username, webaideType, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **body** | [**WebaidesWebaideTypeBody**](WebaidesWebaideTypeBody.md)|  | [optional] 

### Return type

[**InlineResponse20023**](InlineResponse20023.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newWebAideEntry"></a>
# **newWebAideEntry**
> InlineResponse20024 newWebAideEntry(username, webaideType, webaideId, opts)



Create a new WebAide Entry. Note that invalid fields may simply be ignored, rather than generate an actual error. E.g. an invalid “E-mail Address” field will simply result in that field being omitted in the new entry. We recommend that you validate your own data and not rely on request errors to do the validation for you.  Note: Each WebAide is limited to 25,000 entries by default. If your WebAide has this many entries (or more), then this NewWebAideEntry command will return an error. If you need larger WebAides, please contact support. Very large WebAides may require the use of a dedicated server.  See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Change Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let opts = { 
  'body': new Luxsci.WebaideTypeWebaideIdBody(), // WebaideTypeWebaideIdBody | 
};
apiInstance.newWebAideEntry(username, webaideType, webaideId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **body** | [**WebaideTypeWebaideIdBody**](WebaideTypeWebaideIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20024**](InlineResponse20024.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateWebAideEntry"></a>
# **updateWebAideEntry**
> InlineResponse20025 updateWebAideEntry(username, webaideType, webaideId, entryId, opts)



Update an existing WebAide Entry. This function will replace the data in all entry fields with the new data supplied. It is recommended that you retrieve the complete entry, alter it, and then update it – so that you update does not delete data from an entry simply because you did not include those fields in your update.  File attachments on entries are unaffected by this command.   See also [WebAide definitions](/rest-api/webaides.html).  {{ACL: Access to that specific type of WebAides; Add/Change Accessible WebAides and Entries }}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.WebAidesApi

let username = "username_example"; // String | 
let webaideType = "webaideType_example"; // String | 
let webaideId = "webaideId_example"; // String | 
let entryId = "entryId_example"; // String | 
let opts = { 
  'body': new Luxsci.WebaideIdEntryIdBody(), // WebaideIdEntryIdBody | 
};
apiInstance.updateWebAideEntry(username, webaideType, webaideId, entryId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **webaideType** | **String**|  | 
 **webaideId** | **String**|  | 
 **entryId** | **String**|  | 
 **body** | [**WebaideIdEntryIdBody**](WebaideIdEntryIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20025**](InlineResponse20025.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

